@@ -49,16 +49,10 @@ def save_guidance_csv(df, ticker, filename):
     """
     pathname = filename  # CWD + "\\DATA\\" + filename + "\\"  # .replace(r,'')
 
-    for i, row in df.iterrows():
-        for col in row.index:
-            val = row[col]
-            val = str(val)
-
-            df = df.iloc[3:, 1:]
-            df = df.dropna(axis=1, how="all")
-
-            df.columns = df.iloc[0]
-            df = df.drop(df.index[0])
+    df = df.iloc[3:, 1:]  # remove extraneous columns & rows
+    df = df.dropna(axis=1, how="all")  # remove columns that have no data
+    df.columns = df.iloc[0]  # fix columns to have proper titles
+    df = df.drop(df.index[0])  # drop duplicated row
     df.to_csv(pathname + "/" + ticker + "_guidance.csv")
     print(ticker + " guidance done")
     return df
